@@ -43,3 +43,6 @@ DEVCLASS_ENERGY_METER = "65"
 OPTIMIZERS_VIA_INVERTER = "253"
 ENERGY_METER_VIA_INVERTER = "254"
 DEVICE_INFO = "255"
+
+ENTITY_CATEGORY_CONFIG = "config"
+ENTITY_CATEGORY_DIAGNOSTIC = "diagnostic"
